[SCM] exiv2 packaging branch, master, updated. debian/0.25-3.1-3734-gdcbc29a

Maximiliano Curia maxy at moszumanska.debian.org
Thu Jul 13 17:44:52 UTC 2017


Gitweb-URL: http://git.debian.org/?p=pkg-kde/kde-extras/exiv2.git;a=commitdiff;h=0df8356

The following commit has been merged in the master branch:
commit 0df8356a56857b305e8b9f7b454c8d75ae539015
Author: Robin Mills <robin at clanmills.com>
Date:   Thu Feb 12 01:24:26 2015 +0000

    #1029.  Thank You, Thomas for reporting this and providing the patch.
---
 config/config.h.cmake                  | 10 +++++-----
 contrib/organize/organize.cpp          |  2 +-
 include/exiv2/actions.hpp              |  4 ++--
 include/exiv2/basicio.hpp              |  4 ++--
 include/exiv2/exv_msvc-webready.h      |  6 +++---
 include/exiv2/exv_msvc.h               |  6 +++---
 include/exiv2/utilsvideo.hpp           |  2 +-
 msvc2003/exivsimple/exivsimple.cpp     |  2 +-
 msvc2005/tools/depends/src/depends.cpp |  2 +-
 msvc2005/tools/issue984/issue984.cpp   |  4 ++--
 msvc2005/tools/rm/rm.cpp               |  2 +-
 samples/geotag.cpp                     |  4 ++--
 src/jp2image.cpp                       | 14 +++++++-------
 src/preview.cpp                        |  2 +-
 src/properties.cpp                     | 10 +++++-----
 src/psdimage.cpp                       |  2 +-
 src/sonymn.cpp                         |  2 +-
 src/tags.cpp                           |  8 ++++----
 src/utils.hpp                          |  2 +-
 src/utilsvideo.cpp                     |  2 +-
 xmpsdk/include/TXMPIterator.hpp        |  2 +-
 xmpsdk/include/TXMPUtils.hpp           |  2 +-
 xmpsdk/src/ParseRDF.cpp                |  2 +-
 xmpsdk/src/XMPIterator.cpp             |  2 +-
 xmpsdk/src/XMPMeta-Parse.cpp           |  2 +-
 xmpsdk/src/XMPUtils-FileInfo.cpp       |  2 +-
 26 files changed, 51 insertions(+), 51 deletions(-)

diff --git a/config/config.h.cmake b/config/config.h.cmake
index 0d629a2..589d9eb 100644
--- a/config/config.h.cmake
+++ b/config/config.h.cmake
@@ -208,13 +208,13 @@ typedef int pid_t;
 #define EXV_HAVE_GXXCLASSVISIBILITY
 #endif
      
-/* File path seperator */
+/* File path separator */
 #if defined(WIN32) && !defined(__CYGWIN__)
-#define EXV_SEPERATOR_STR "\"
-#define EXV_SEPERATOR_CHR '\'
+#define EXV_SEPARATOR_STR "\"
+#define EXV_SEPARATOR_CHR '\'
 #else
-#define EXV_SEPERATOR_STR "/"
-#define EXV_SEPERATOR_CHR '/'
+#define EXV_SEPARATOR_STR "/"
+#define EXV_SEPARATOR_CHR '/'
 #endif
 
 /* Shared library support, see http://gcc.gnu.org/wiki/Visibility */
diff --git a/contrib/organize/organize.cpp b/contrib/organize/organize.cpp
index 40e090a..5144da4 100644
--- a/contrib/organize/organize.cpp
+++ b/contrib/organize/organize.cpp
@@ -349,7 +349,7 @@ int main(int argc, char* argv[])
     po::options_description hidden("Hidden Options");
     hidden.add_options()
         ("source-dir", po::value< std::string >(), "directory of files to organize, may end in file wildcard")
-        ("dest-dir", po::value< std::string >(), "desination directory for files, may not be within source-dir")
+        ("dest-dir", po::value< std::string >(), "designation directory for files, may not be within source-dir")
         ("pattern", po::value< std::string >(), "subdirectory pattern for grouping files within dest-dir")
         ;
 
diff --git a/include/exiv2/actions.hpp b/include/exiv2/actions.hpp
index d470d91..a4ba1df 100644
--- a/include/exiv2/actions.hpp
+++ b/include/exiv2/actions.hpp
@@ -134,7 +134,7 @@ namespace Action {
           prototype is replaced.
 
           @param type Task type.
-          @param task Pointer to the prototype. Ownership is transfered to the
+          @param task Pointer to the prototype. Ownership is transferred to the
                  task factory. That's what the auto pointer indicates.
         */
         void registerTask(TaskType type, Task::AutoPtr task);
@@ -356,7 +356,7 @@ namespace Action {
 
     private:
         virtual Modify* clone_() const;
-        //! Copy contructor needed because of AutoPtr member
+        //! Copy constructor needed because of AutoPtr member
         Modify(const Modify& /*src*/) : Task() {}
 
         //! Add a metadatum to \em pImage according to \em modifyCmd
diff --git a/include/exiv2/basicio.hpp b/include/exiv2/basicio.hpp
index cdff855..23d28d1 100644
--- a/include/exiv2/basicio.hpp
+++ b/include/exiv2/basicio.hpp
@@ -792,12 +792,12 @@ namespace Exiv2 {
     class EXIV2API XPathIo : public FileIo {
     public:
         /*!
-            @brief The extention of the temporary file which is created when getting input data
+            @brief The extension of the temporary file which is created when getting input data
                     to read metadata. This file will be deleted in destructor.
         */
         static const std::string TEMP_FILE_EXT;
         /*!
-            @brief The extention of the generated file which is created when getting input data
+            @brief The extension of the generated file which is created when getting input data
                     to add or modify the metadata.
         */
         static const std::string GEN_FILE_EXT;
diff --git a/include/exiv2/exv_msvc-webready.h b/include/exiv2/exv_msvc-webready.h
index 8ea2887..e7f8236 100644
--- a/include/exiv2/exv_msvc-webready.h
+++ b/include/exiv2/exv_msvc-webready.h
@@ -111,9 +111,9 @@ typedef int pid_t;
 #pragma comment(lib, "ws2_32.lib")
 #pragma comment(lib, "wldap32.lib")
 
-/* File path seperator */
-#define EXV_SEPERATOR_STR "\"
-#define EXV_SEPERATOR_CHR '\'
+/* File path separator */
+#define EXV_SEPARATOR_STR "\"
+#define EXV_SEPARATOR_CHR '\'
 
 /* Windows unicode path support */
 // #define EXV_UNICODE_PATH
diff --git a/include/exiv2/exv_msvc.h b/include/exiv2/exv_msvc.h
index 39a14cd..a7419c5 100644
--- a/include/exiv2/exv_msvc.h
+++ b/include/exiv2/exv_msvc.h
@@ -111,9 +111,9 @@ typedef int pid_t;
 #pragma comment(lib, "ws2_32.lib")
 #pragma comment(lib, "wldap32.lib")
 
-/* File path seperator */
-#define EXV_SEPERATOR_STR "\"
-#define EXV_SEPERATOR_CHR '\'
+/* File path separator */
+#define EXV_SEPARATOR_STR "\"
+#define EXV_SEPARATOR_CHR '\'
 
 /* Windows unicode path support */
 // #define EXV_UNICODE_PATH
diff --git a/include/exiv2/utilsvideo.hpp b/include/exiv2/utilsvideo.hpp
index 1cbb386..92cc6df 100644
--- a/include/exiv2/utilsvideo.hpp
+++ b/include/exiv2/utilsvideo.hpp
@@ -36,7 +36,7 @@ class UtilsVideo
 public:
     static bool compareTagValue(Exiv2::DataBuf &buf, const char *str);
     static bool compareTagValue(Exiv2::DataBuf& buf,const char arr[][5],int32_t arraysize);
-    static bool simpleBytesComparision(Exiv2::DataBuf& buf ,const char* str,int32_t size);
+    static bool simpleBytesComparison(Exiv2::DataBuf& buf ,const char* str,int32_t size);
 }; // class UtilsVideo
 
 } // namespace Exiv2
diff --git a/msvc2003/exivsimple/exivsimple.cpp b/msvc2003/exivsimple/exivsimple.cpp
index f85e353..4c7a9c7 100644
--- a/msvc2003/exivsimple/exivsimple.cpp
+++ b/msvc2003/exivsimple/exivsimple.cpp
@@ -353,7 +353,7 @@ EXIVSIMPLE_API int AddMeta(HIMAGE img, const char *key, const char *val, DllType
     return rc;
 }
 
-// If multiple entires exist, this only remove the first one
+// If multiple entries exist, this only remove the first one
 // found. Call multiple times to remove many.
 // Returns 0 on success
 EXIVSIMPLE_API int RemoveMeta(HIMAGE img, const char *key)
diff --git a/msvc2005/tools/depends/src/depends.cpp b/msvc2005/tools/depends/src/depends.cpp
index f587eea..ccd38a0 100644
--- a/msvc2005/tools/depends/src/depends.cpp
+++ b/msvc2005/tools/depends/src/depends.cpp
@@ -85,7 +85,7 @@ LPCTSTR getModuleBase(PMODULE_FILE_INFO pModule,BOOL bQuiet)
 	LPCTSTR base = pModule->GetBaseName() ;
     LPCTSTR result = base ;
     if ( bQuiet ) {
-        // keep quiet about these guys - they're build/compiler dependant
+        // keep quiet about these guys - they're build/compiler dependent
 	    if (   _strnicmp(base,"MSVCR",5) == 0 ) result = NULL ;
 	    if (   _strnicmp(base,"MSVCP",5) == 0 ) result = NULL ;
 	    if (   _strnicmp(base,"API-MS-Win",10) == 0 ) result = NULL ;
diff --git a/msvc2005/tools/issue984/issue984.cpp b/msvc2005/tools/issue984/issue984.cpp
index 606d8ab..48682ce 100644
--- a/msvc2005/tools/issue984/issue984.cpp
+++ b/msvc2005/tools/issue984/issue984.cpp
@@ -3,9 +3,9 @@
 
 int main(int argc, char** argv)
 {
-    printf("Opening file '%s' with FILE_SHARE_DELETE acess...
", argv[1]);
+    printf("Opening file '%s' with FILE_SHARE_DELETE access...
", argv[1]);
 
-    HANDLE hFile = CreateFile(argv[1], GENERIC_READ,
+    HANDLE hFile = CreateFileA(argv[1], GENERIC_READ,
             FILE_SHARE_DELETE|FILE_SHARE_READ|FILE_SHARE_WRITE,
             NULL, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, NULL);
 
diff --git a/msvc2005/tools/rm/rm.cpp b/msvc2005/tools/rm/rm.cpp
index 4329de2..56f503c 100644
--- a/msvc2005/tools/rm/rm.cpp
+++ b/msvc2005/tools/rm/rm.cpp
@@ -195,7 +195,7 @@ BOOL empty_directory(wchar_t* name, BOOL force, BOOL verbose, BOOL quiet){
  * option is TRUE, directories will be recursively emptied then deleted.
  * If force is TRUE, file attributes will be changed to allow the program
  * to delete the file.  The verbose option will cause non-fatal error messages
- * to print to stderr.  The quiet option will supress all but fatal
+ * to print to stderr.  The quiet option will suppress all but fatal
  * error messages
  */
 BOOL del(wchar_t* name, BOOL recurse, BOOL force, BOOL verbose, BOOL quiet) {
diff --git a/samples/geotag.cpp b/samples/geotag.cpp
index 0d50347..71e6b5c 100644
--- a/samples/geotag.cpp
+++ b/samples/geotag.cpp
@@ -916,12 +916,12 @@ int main(int argc,const char* argv[])
    char* filename = "crt_stat.c";
    errno_t err;
 
-   // Get data associated with "crt_stat.c": 
+   // Get data associated with "crt_stat.c":
    result = _stat( filename, &buf );
 
    int _utime(
    const char *filename,
-   struct _utimbuf *times 
+   struct _utimbuf *times
 );
    */
 
diff --git a/src/jp2image.cpp b/src/jp2image.cpp
index e8c3806..56a49e2 100644
--- a/src/jp2image.cpp
+++ b/src/jp2image.cpp
@@ -171,7 +171,7 @@ namespace Exiv2
 #ifdef DEBUG
             std::cout << "Exiv2::Jp2Image::readMetadata: Position: " << position << "
";
             std::cout << "Exiv2::Jp2Image::readMetadata: Find box type: " << std::string((const char*)&box.boxType)
-                      << " lenght: " << box.boxLength << "
";
+                      << " length: " << box.boxLength << "
";
 #endif
             box.boxType   = getLong((byte*)&box.boxType, bigEndian);
 
@@ -415,7 +415,7 @@ namespace Exiv2
 
 #ifdef DEBUG
             std::cout << "Exiv2::Jp2Image::doWriteMetadata: Find box type: " << bheaderBuf.pData_ + 4
-                      << " lenght: " << box.boxLength << "
";
+                      << " length: " << box.boxLength << "
";
 #endif
 
             if (box.boxLength == 0)
@@ -459,7 +459,7 @@ namespace Exiv2
                 {
 
 #ifdef DEBUG
-                    std::cout << "Exiv2::Jp2Image::doWriteMetadata: Write JP2Header box (lenght: " << box.boxLength << ")
";
+                    std::cout << "Exiv2::Jp2Image::doWriteMetadata: Write JP2Header box (length: " << box.boxLength << ")
";
 #endif
                     if (outIo.write(boxBuf.pData_, boxBuf.size_) != boxBuf.size_) throw Error(21);
 
@@ -488,7 +488,7 @@ namespace Exiv2
                             memcpy(boxData.pData_ + 8 + 16, rawExif.pData_, rawExif.size_);
 
 #ifdef DEBUG
-                            std::cout << "Exiv2::Jp2Image::doWriteMetadata: Write box with Exif metadata (lenght: "
+                            std::cout << "Exiv2::Jp2Image::doWriteMetadata: Write box with Exif metadata (length: "
                                       << boxData.size_ << ")
";
 #endif
                             if (outIo.write(boxData.pData_, boxData.size_) != boxData.size_) throw Error(21);
@@ -511,7 +511,7 @@ namespace Exiv2
                             memcpy(boxData.pData_ + 8 + 16, rawIptc.pData_, rawIptc.size_);
 
 #ifdef DEBUG
-                            std::cout << "Exiv2::Jp2Image::doWriteMetadata: Write box with Iptc metadata (lenght: "
+                            std::cout << "Exiv2::Jp2Image::doWriteMetadata: Write box with Iptc metadata (length: "
                                       << boxData.size_ << ")
";
 #endif
                             if (outIo.write(boxData.pData_, boxData.size_) != boxData.size_) throw Error(21);
@@ -541,7 +541,7 @@ namespace Exiv2
                         memcpy(boxData.pData_ + 8 + 16, xmp.pData_,   xmp.size_);
 
 #ifdef DEBUG
-                        std::cout << "Exiv2::Jp2Image::doWriteMetadata: Write box with XMP metadata (lenght: "
+                        std::cout << "Exiv2::Jp2Image::doWriteMetadata: Write box with XMP metadata (length: "
                                   << boxData.size_ << ")
";
 #endif
                         if (outIo.write(boxData.pData_, boxData.size_) != boxData.size_) throw Error(21);
@@ -583,7 +583,7 @@ namespace Exiv2
                 default:
                 {
 #ifdef DEBUG
-                    std::cout << "Exiv2::Jp2Image::doWriteMetadata: write box (lenght: " << box.boxLength << ")
";
+                    std::cout << "Exiv2::Jp2Image::doWriteMetadata: write box (length: " << box.boxLength << ")
";
 #endif
                     if (outIo.write(boxBuf.pData_, boxBuf.size_) != boxBuf.size_) throw Error(21);
 
diff --git a/src/preview.cpp b/src/preview.cpp
index e174023..9235389 100644
--- a/src/preview.cpp
+++ b/src/preview.cpp
@@ -767,7 +767,7 @@ namespace {
         for (ExifData::const_iterator pos = exifData.begin(); pos != exifData.end(); ++pos) {
             if (pos->groupName() == group_) {
                 /*
-                   Write only the neccessary TIFF image tags
+                   Write only the necessary TIFF image tags
                    tags that especially could cause problems are:
                    "NewSubfileType" - the result is no longer a thumbnail, it is a standalone image
                    "Orientation" - this tag typically appears only in the "Image" group. Deleting it ensures
diff --git a/src/psdimage.cpp b/src/psdimage.cpp
index 2d84986..117fb6e 100644
--- a/src/psdimage.cpp
+++ b/src/psdimage.cpp
@@ -195,7 +195,7 @@ namespace Exiv2 {
             throw Error(3, "Photoshop");
         }
 
-        // after the color data section, comes a list of resource blocks, preceeded by the total byte size
+        // after the color data section, comes a list of resource blocks, preceded by the total byte size
         if (io_->read(buf, 4) != 4)
         {
             throw Error(3, "Photoshop");
diff --git a/src/sonymn.cpp b/src/sonymn.cpp
index 0135b80..4152fdd 100644
--- a/src/sonymn.cpp
+++ b/src/sonymn.cpp
@@ -461,7 +461,7 @@ namespace Exiv2 {
                 N_("Release Mode"),
                 sony1Id, makerTags, unsignedShort, -1, EXV_PRINT_TAG(sonyReleaseMode)),
         TagInfo(0xB04A, "SequenceNumber", N_("Sequence Number"),
-                N_("Shot number in continous burst mode"),
+                N_("Shot number in continuous burst mode"),
                 sony1Id, makerTags, unsignedShort, -1, EXV_PRINT_TAG(sonySequenceNumber)),
         TagInfo(0xB04B, "AntiBlur", N_("Anti-Blur"),
                 N_("Anti-Blur"),
diff --git a/src/tags.cpp b/src/tags.cpp
index 4ba4f5b..e7e8ef1 100644
--- a/src/tags.cpp
+++ b/src/tags.cpp
@@ -299,8 +299,8 @@ namespace Exiv2 {
         { 34892, N_("Linear Raw")         }
     };
 
-    //! Threshholding, tag 0x0107
-    extern const TagDetails exifThreshholding[] = {
+    //! Thresholding, tag 0x0107
+    extern const TagDetails exifThresholding[] = {
         { 1, N_("No dithering or halftoning")           },
         { 2, N_("Ordered dither or halftone technique") },
         { 3, N_("Randomized process")                   }
@@ -441,10 +441,10 @@ namespace Exiv2 {
                 N_("The pixel composition. In JPEG compressed data a JPEG "
                 "marker is used instead of this tag."),
                 ifd0Id, imgStruct, unsignedShort, 1, EXV_PRINT_TAG(exifPhotometricInterpretation)),
-        TagInfo(0x0107, "Threshholding", N_("Threshholding"),
+        TagInfo(0x0107, "Thresholding", N_("Thresholding"),
                 N_("For black and white TIFF files that represent shades of gray, "
                    "the technique used to convert from gray to black and white pixels."),
-                ifd0Id, imgStruct, unsignedShort, 1, EXV_PRINT_TAG(exifThreshholding)), // TIFF tag
+                ifd0Id, imgStruct, unsignedShort, 1, EXV_PRINT_TAG(exifThresholding)), // TIFF tag
         TagInfo(0x0108, "CellWidth", N_("Cell Width"),
                 N_("The width of the dithering or halftoning matrix used to create a "
                    "dithered or halftoned bilevel file."),
diff --git a/src/utils.hpp b/src/utils.hpp
index 146d533..46c249f 100644
--- a/src/utils.hpp
+++ b/src/utils.hpp
@@ -161,7 +161,7 @@ private:
     bool strtol(const char* nptr, long& n);
 
     /*!
-      @brief Replaces all occurences of \em searchText in the \em text string
+      @brief Replaces all occurrences of \em searchText in the \em text string
              by \em replaceText.
      */
     void replace(std::string& text, const std::string& searchText, const std::string& replaceText);
diff --git a/src/utilsvideo.cpp b/src/utilsvideo.cpp
index b9f70b9..a5d41db 100644
--- a/src/utilsvideo.cpp
+++ b/src/utilsvideo.cpp
@@ -50,7 +50,7 @@ bool UtilsVideo::compareTagValue(Exiv2::DataBuf& buf,const char arr[][5],int32_t
     return result;
 }
 
-bool UtilsVideo::simpleBytesComparision(Exiv2::DataBuf& buf ,const char* str,int32_t size){
+bool UtilsVideo::simpleBytesComparison(Exiv2::DataBuf& buf ,const char* str,int32_t size){
     for(int32_t i=0; i<size; i++ )
         if(toupper(buf.pData_[i]) != str[i])
             return false;
diff --git a/xmpsdk/include/TXMPIterator.hpp b/xmpsdk/include/TXMPIterator.hpp
index 8c90fce..33c73a1 100644
--- a/xmpsdk/include/TXMPIterator.hpp
+++ b/xmpsdk/include/TXMPIterator.hpp
@@ -62,7 +62,7 @@
 /// are visited next. The fields of a struct or items of an array are visited after the qualifiers
 /// of the parent.
 ///
-/// You can specify options when contructing the iteration object to control how the iteration is
+/// You can specify options when constructing the iteration object to control how the iteration is
 /// performed.
 ///
 ///   \li 
diff --git a/src/properties.cpp b/src/properties.cpp
index bdc2343..2fa7b5e 100644
--- a/src/properties.cpp
+++ b/src/properties.cpp
@@ -1373,7 +1373,7 @@ namespace Exiv2 {
         { "MediaLangCode",      N_("Media Language Code"),          "Integer",               xmpText, xmpExternal, N_("A 16-bit integer that specifies the language code for this media.")   },
         { "MediaModifyDate",    N_("Media Track Modify Date"),      "Integer",               xmpText, xmpExternal, N_("A 32-bit integer that indicates (in seconds since midnight, January 1, 1904) when the media header was last modified.")   },
         { "MediaTimeScale",     N_("Media Time Scale"),             "Integer",               xmpText, xmpExternal, N_("A time value that indicates the time scale for this media-that is, the number of time units that pass per second in its time coordinate system." )   },
-        { "OutputSampleRate",   N_("Output Audio Sample Rate"),     "Integer",               xmpText, xmpExternal, N_("The ouput audio sample rate. Can be any value, but commonly 32000, 41100, or 48000.") },
+        { "OutputSampleRate",   N_("Output Audio Sample Rate"),     "Integer",               xmpText, xmpExternal, N_("The output audio sample rate. Can be any value, but commonly 32000, 41100, or 48000.") },
         { "SampleCount",        N_("Audio Sample Count"),           "Integer",               xmpText, xmpExternal, N_("Sample taken for Analyzing Audio Stream")   },
         { "SampleRate",         N_("Audio Sample Rate"),            "Integer",               xmpText, xmpExternal, N_("The audio sample rate. Can be any value, but commonly 32000, 41100, or 48000.") },
         { "SampleType",         N_("Audio Sample Type"),            "closed Choice of Text", xmpText, xmpExternal, N_("The audio sample type. One of: 8Int, 16Int, 32Int, 32Float.") },
@@ -1438,11 +1438,11 @@ namespace Exiv2 {
                                                 N_("A list (concatenated and separated) of additional measurements, facts, characteristics, or assertions about the record. Meant to provide a mechanism for structured content such as key-value pairs.")
             },
 
-        // Occurence Level Class
-        { "Occurence",                      N_("Occurence"),                         "Occurence",    xmpText,   xmpInternal, 
+        // Occurrence Level Class
+        { "Occurrence",                      N_("Occurrence"),                         "Occurrence",    xmpText,   xmpInternal, 
                                             N_("The category of information pertaining to evidence of an occurrence in nature, in a collection, or in a dataset (specimen, observation, etc.)."),
         },
             // Occurence Level Terms
             { "occurrenceID",                   N_("Occurrence ID"),                        "Text",      xmpText,   xmpExternal,      
                                                 N_("An identifier for the Occurrence (as opposed to a particular digital record of the occurrence). In the absence of a persistent global unique identifier, construct one from a combination of identifiers in the record that will most closely make the occurrenceID globally unique.")
             },
@@ -1537,7 +1537,7 @@ namespace Exiv2 {
                                                 N_("The amount of effort expended during an Event.")
             },
             { "Date",                           N_("Event Date"),                  "Date",      xmpText,    xmpExternal,      
-                                                N_("The date-time or interval during which an Event occured. For occurrences, this is the date-time when the event was recorded. Not suitable for a time in a geological context. Recommended best practice is to use an encoding scheme, such as ISO 8601:2004(E).")
+                                                N_("The date-time or interval during which an Event occurred. For occurrences, this is the date-time when the event was recorded. Not suitable for a time in a geological context. Recommended best practice is to use an encoding scheme, such as ISO 8601:2004(E).")
             },
             { "earliestDate",                   N_("Event Earliest Date"),                  "Date",      xmpText,    xmpExternal,      
                                                 N_("The date-time or interval during which an Event started. For occurrences, this is the date-time when the event was recorded. Not suitable for a time in a geological context. Recommended best practice is to use an encoding scheme, such as ISO 8601:2004(E).")
@@ -1438,11 +1438,11 @@ namespace Exiv2 {
                                             N_("The category of information pertaining to evidence of an occurrence in nature, in a collection, or in a dataset (specimen, observation, etc.)."),
         },
-            // Occurence Level Terms
+            // Occurrence Level Terms
             { "occurrenceID",                   N_("Occurrence ID"),                        "Text",      xmpText,   xmpExternal,      
                                                 N_("An identifier for the Occurrence (as opposed to a particular digital record of the occurrence). In the absence of a persistent global unique identifier, construct one from a combination of identifiers in the record that will most closely make the occurrenceID globally unique.")
-- 
exiv2 packaging



More information about the pkg-kde-commits mailing list